# Generated by roxygen2: do not edit by hand

S3method(plot,gpciImpSam)
S3method(summary,gpciImpSam)
export(capability)
export(compute_theoretical_moments)
export(define_distribution)
export(dist_exponential)
export(dist_gamma)
export(dist_logistic_exponential)
export(dist_normal)
export(dist_weibull)
export(fit_distribution)
export(gpci_impsam)
export(heidelberger_welch)
export(hpd_interval)
export(impsam_gpci)
importFrom(boot,boot)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,rgb)
importFrom(graphics,curve)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,title)
importFrom(numDeriv,grad)
importFrom(numDeriv,hessian)
importFrom(stats,deriv)
importFrom(stats,dgamma)
importFrom(stats,dnorm)
importFrom(stats,integrate)
importFrom(stats,median)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,quantile)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,var)
