#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom stats optimize optim var sd median quantile rnorm runif rgamma dnorm dgamma deriv integrate uniroot
#' @importFrom graphics plot lines points legend grid title par hist curve layout
#' @importFrom grDevices rgb adjustcolor
#' @importFrom numDeriv hessian grad
#' @importFrom boot boot
## usethis namespace: end
NULL
