% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{compute_theoretical_moments}
\alias{compute_theoretical_moments}
\title{Theoretical Moments Computation for Process Distribution}
\usage{
compute_theoretical_moments(distribution)
}
\arguments{
\item{distribution}{A \code{gpci_dist} distribution object.}
}
\value{
A list with \code{mean} and \code{var}.
}
\description{
Computes numerical or analytical mean and variance for a \code{gpci_dist} object.
}
\examples{
compute_theoretical_moments(dist_normal(mean = 5, sd = 2))
}
