% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot.gpciImpSam}
\alias{plot.gpciImpSam}
\title{Plot Method for gpciImpSam Objects}
\usage{
\method{plot}{gpciImpSam}(x, type = c("density", "trace"), index = NULL, ...)
}
\arguments{
\item{x}{An object of class \code{"gpciImpSam"}.}

\item{type}{Type of plot: \code{"density"} (default) or \code{"trace"}.}

\item{index}{Character string naming the specific GPCI to plot. Default plots the first index.}

\item{...}{Additional graphical parameters.}
}
\value{
Invisible \code{NULL}.
}
\description{
Visualizes GPCI posterior density distributions, trace plots, and HPD intervals.
}
\examples{
data_x <- rnorm(40, mean = 10, sd = 1)
fit <- impsam_gpci(data = data_x, distribution = dist_normal(), USL = 13, LSL = 7)
plot(fit, type = "density", index = "Cpy")
}
