% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{dist_weibull}
\alias{dist_weibull}
\title{Standard Pre-defined Weibull Distribution}
\usage{
dist_weibull(shape = 1, scale = 1)
}
\arguments{
\item{shape}{Shape parameter (default is 1).}

\item{scale}{Scale parameter (default is 1).}
}
\value{
A \code{gpci_dist} object.
}
\description{
Standard Pre-defined Weibull Distribution
}
\examples{
d_weib <- dist_weibull(shape = 2, scale = 5)
}
