% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{summary.gpciImpSam}
\alias{summary.gpciImpSam}
\title{Summary and Diagnostics for gpciImpSam Objects}
\usage{
\method{summary}{gpciImpSam}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"gpciImpSam"}.}

\item{...}{Additional arguments.}
}
\value{
A data frame containing diagnostic metrics for each evaluated GPCI.
}
\description{
Computes estimated value, bias, MSE, Risk value, HPD intervals at 90\%, 95\%, and 99\% significance levels,
Heidelberger and Welch MCMC convergence diagnostic, and convergence probability.
}
\examples{
data_x <- rnorm(40, mean = 10, sd = 1)
fit_imp <- impsam_gpci(data = data_x, distribution = dist_normal(), USL = 13, LSL = 7)
summary(fit_imp)
}
