% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{dist_logistic_exponential}
\alias{dist_logistic_exponential}
\title{Pre-defined Logistic-Exponential Distribution}
\usage{
dist_logistic_exponential(alpha = 1, lambda = 1)
}
\arguments{
\item{alpha}{Scale/shape parameter (default is 1).}

\item{lambda}{Scale/shape parameter (default is 1).}
}
\value{
A \code{gpci_dist} object.
}
\description{
Pre-defined Logistic-Exponential Distribution
}
\examples{
d_le <- dist_logistic_exponential(alpha = 1, lambda = 1)
}
