% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{dist_gamma}
\alias{dist_gamma}
\title{Standard Pre-defined Gamma Distribution}
\usage{
dist_gamma(shape = 1, rate = 1)
}
\arguments{
\item{shape}{Shape parameter (default is 1).}

\item{rate}{Rate parameter (default is 1).}
}
\value{
A \code{gpci_dist} object.
}
\description{
Standard Pre-defined Gamma Distribution
}
\examples{
d_gam <- dist_gamma(shape = 2, rate = 1)
}
