% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{dist_exponential}
\alias{dist_exponential}
\title{Standard Pre-defined Exponential Distribution}
\usage{
dist_exponential(rate = 1)
}
\arguments{
\item{rate}{Rate parameter (default is 1).}
}
\value{
A \code{gpci_dist} object.
}
\description{
Standard Pre-defined Exponential Distribution
}
\examples{
d_exp <- dist_exponential(rate = 0.5)
}
