% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{safe_uniroot}
\alias{safe_uniroot}
\title{Safe Root Finder Helper}
\usage{
safe_uniroot(f, interval, ...)
}
\arguments{
\item{f}{Objective function.}

\item{interval}{Numeric vector of length 2 defining search range.}

\item{...}{Additional arguments passed to \code{f}.}
}
\value{
Numeric scalar solution.
}
\description{
Solves 1D non-linear equation f(x) = 0 safely within given interval.
}
\keyword{internal}
