% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{dist_normal}
\alias{dist_normal}
\title{Standard Pre-defined Normal Distribution}
\usage{
dist_normal(mean = 0, sd = 1)
}
\arguments{
\item{mean}{Distribution mean (default is 0).}

\item{sd}{Distribution standard deviation (default is 1).}
}
\value{
A \code{gpci_dist} object.
}
\description{
Standard Pre-defined Normal Distribution
}
\examples{
d_norm <- dist_normal(mean = 10, sd = 2)
}
